# BABAPPA Documentation

- [Installation](installation.md)
- [Quickstart](quickstart.md)
- [Theory to Implementation](theory_to_implementation.md)
- [Command Reference](command_reference.md)
- [Configuration](configuration.md)
- [Sensitivity Analysis](sensitivity_analysis.md)
- [Interpretation for Biologists](interpretation.md)
- [Benchmarking](benchmarking.md)
- [Developer Guide](developer.md)
- [FAQ](faq.md)
